@@ -13,3 +13,15 @@ test_that("(de)compression works for arbitrary objects", {
                                                    LETTERS)))
   expect_identical(x, uncompress_chars(compress_chars(x)))
 })
+
+test_that("set_attr handles objects correctly", {
+  d <- Sys.Date()
+  attr(d, "test_atr") <- "test_val"
+  dd <- d
+  attributes(dd) <- NULL
+  expect_false(identical(dd, d))
+
+  .Call(C_set_attr, dd, as.pairlist(attributes(d)))
+  expect_true(is.object(dd))
+  expect_identical(dd, d)
+})
